@@ -1,8 +1,7 @@
 package Catalyst::ActionRole::Zoo;
 
 use Moose::Role;
-
-use namespace::autoclean;
+use namespace::clean -except => [ 'meta' ];
 
 after execute => sub {
     my ($self, $controller, $c) = @_;
